@@ -1,21 +1,16 @@
 // the frontend file for call from R
 
-#include <stdio.h>
-#include <string.h>
-#include <time.h>
+#include <cstring>
+#include <ctime>
+#include <cstdio>
+#include <cstdlib>
 
 #include "general.h"  // general constants and data type definitions
 // here you specify weather to compile for  Windows or UNIX
 
-#if defined(R_PORT)
-#include <R.h>
-#include <Rinternals.h>
-#else
-#define Rprintf printf
-#endif
 #if defined(DEBUG)
 #if defined(MICROSOFT)
-#include <malloc.h>  // for heapcheck
+#include <cmalloc>  // for heapcheck
 #endif
 #endif
 
@@ -34,6 +29,14 @@
 #include "calibrate.h"
 #include "Rfront.h"
 
+#if defined(R_PORT)
+#include <R.h>
+#include <Rinternals.h>
+#include <R_ext/Rdynload.h>
+#else
+#define Rprintf printf
+#endif
+
 #if defined(DEBUG_NEW)
 extern int SetSize;
 #endif
@@ -44,10 +47,66 @@ extern estDsc estName[];
 extern estDsc estNameReg[];
 extern char VersionString[];
 
+using namespace std ;
+
 extern "C" {
 
 marray<dataStore*> allModels; // stores pointers to all the active models, one for each
 
+
+#define CALLDEF(name, n)  {#name, (DL_FUNC) &name, n}
+
+const static R_CallMethodDef R_CallDef[] = {
+   CALLDEF(exportModelRT,1),
+   CALLDEF(exportModelT,1),
+   CALLDEF(exportProximity,2),
+   CALLDEF(printTree2R,1),
+   CALLDEF(printTreeDot2R,1),
+   CALLDEF(exportSizesRF,1),
+   CALLDEF(exportSumOverLeavesRF,1),
+   CALLDEF(exportModel,1),
+   CALLDEF(noEqualRows,7),
+
+   {NULL, NULL, 0}
+};
+
+const static R_CMethodDef R_CDef[] = {
+   CALLDEF(exportVarImportanceCluster, 3),
+   CALLDEF(initCore, 1),
+   CALLDEF(destroyCore, 0),
+   CALLDEF(versionCore, 1),
+   CALLDEF(destroyOneCoreModel, 1),
+   CALLDEF(buildCoreModel, 15),
+   CALLDEF(predictWithCoreModel, 11),
+   CALLDEF(estimateCoreReg, 16),
+   CALLDEF(estimateCore, 17),
+   CALLDEF(rfAttrEval, 2),
+   CALLDEF(rfOOB, 4),
+   CALLDEF(ordEvalCore, 19),
+   CALLDEF(modelEvaluate, 20),
+   CALLDEF(modelEvaluateReg, 8),
+   CALLDEF(optionsInOut, 3),
+   CALLDEF(saveRF, 2),
+   CALLDEF(readRF, 2),
+   CALLDEF(calibrate, 9),
+   CALLDEF(discretize, 18),
+   CALLDEF(testNA, 3),
+   CALLDEF(testRPORT, 1),
+   CALLDEF(testCoreRand, 2),
+   CALLDEF(testClassPseudoRandom, 5),
+   CALLDEF(testTime, 1),
+   {NULL, NULL, 0}
+};
+
+void R_init_CORElearn(DllInfo *dll)
+{
+    R_registerRoutines(dll, R_CDef, R_CallDef, NULL, NULL);
+    R_useDynamicSymbols(dll, FALSE);
+    R_forceSymbols(dll, TRUE);
+
+}
+
+
 // on entry to library
 void initCore(int *maxModels) {
 	destroyCore(); // in case of multiple initializations
@@ -66,7 +125,7 @@ void testNA(int *t, double *x, int *a) {
 		*x = y / y;
 	}
 	//u.d = *x;
-	//printf("%08x  %08x", u.i.p1, u.i.p0); // OK for little endian
+	//Rprintf("%08x  %08x", u.i.p1, u.i.p0); // OK for little endian
 	a[0] = isNAcont(*x);
 	a[1] = isNaN(*x);
 }
@@ -339,7 +398,7 @@ void destroyCore() {
 #endif
 
 #if defined(DEBUG_NEW)
-	printf("Still allocated memory blocks: %ld\n",SetSize);
+	Rprintf("Still allocated memory blocks: %ld\n",SetSize);
 #endif
 }
 
@@ -347,17 +406,17 @@ void destroyOneCoreModel(int* modelID) {
 	// is modelID valid
 	if (modelID != 0)
 		if (allModels.defined())
-			if (*modelID >= 0)
-		       if (*modelID < allModels.len())
-		    	   if (allModels[*modelID] != 0) {
-		dataStore *data = allModels[*modelID];
-		if (data->isRegression)
-			delete (regressionTree*) allModels[*modelID];
-		else
-			delete (featureTree*) allModels[*modelID];
-		allModels[*modelID] = 0;
-		*modelID = -1;
-	}
+			if (modelID != 0 && *modelID >= 0)
+				if (*modelID < allModels.len())
+					if (allModels[*modelID] != 0) {
+						dataStore *data = allModels[*modelID];
+						if (data->isRegression)
+							delete (regressionTree*) allModels[*modelID];
+						else
+							delete (featureTree*) allModels[*modelID];
+						allModels[*modelID] = 0;
+						*modelID = -1;
+					}
 }
 
 void availableEstimatorsCore(char **estBrief) {
@@ -1001,7 +1060,7 @@ void discretize(int *methodIdx, int *isRegression, int *noInst, int *noDiscrete,
 				Estimator.discretizeEqualWidth(idx, maxBins[idx-1], attrBounds) ;
 				break ;
 			default: merror("Invalid discretization method in function discretize for regression ","Rfront.cpp") ;
-			         break ;
+			break ;
 			}
 			noBounds[idx] = attrBounds.filled() ;
 			for (j=0 ; j < attrBounds.filled(); j++)
@@ -1033,18 +1092,18 @@ void discretize(int *methodIdx, int *isRegression, int *noInst, int *noDiscrete,
 		estimation Estimator(dT, dT->DTraining, weight, dT->NoTrainCases);
 		for (int idx=0 ; idx < Estimator.noNumeric ; idx++)	{
 			switch (*methodIdx) {
-				case discrGreedy:
-					Estimator.discretizeGreedy(idx, maxBins[idx], attrBounds, Estimator.noDiscrete) ;
-					break ;
-				case discrEqFreq:
-					Estimator.discretizeEqualFrequency(idx, maxBins[idx], attrBounds) ;
-					break ;
-				case discrEqWidth:
-					Estimator.discretizeEqualWidth(idx, maxBins[idx], attrBounds) ;
-					break ;
-				default: merror("Invalid discretization method in function discretize for classification","Rfront.cpp") ;
-				         break ;
-				}
+			case discrGreedy:
+				Estimator.discretizeGreedy(idx, maxBins[idx], attrBounds, Estimator.noDiscrete) ;
+				break ;
+			case discrEqFreq:
+				Estimator.discretizeEqualFrequency(idx, maxBins[idx], attrBounds) ;
+				break ;
+			case discrEqWidth:
+				Estimator.discretizeEqualWidth(idx, maxBins[idx], attrBounds) ;
+				break ;
+			default: merror("Invalid discretization method in function discretize for classification","Rfront.cpp") ;
+			break ;
+			}
 			noBounds[idx] = attrBounds.filled() ;
 			for (j=0 ; j < attrBounds.filled(); j++)
 				bounds[idx*(*noInst)+j] = attrBounds[j] ;
@@ -1187,6 +1246,7 @@ SEXP noEqualRows(SEXP data1, SEXP data2, SEXP nrowsd1, SEXP nrowsd2, SEXP ncols,
 
 #endif
 
+#if !defined(R_PORT)
 void simRcall() {
 	int maxModel = 128;
 	initCore(&maxModel);
@@ -1227,10 +1287,10 @@ void simRcall() {
 			(char**) optionsVal);
 
 	for (i = 0; i < noPredict; i++) {
-		printf("%d  %d  ", i + 1, pred[i]);
+		Rprintf("%d  %d  ", i + 1, pred[i]);
 		for (j = 0; j < noDiscreteValues[0]; j++)
-			printf("%5.3f ", prob[i + j * noPredict]);
-		printf("\n");
+			Rprintf("%5.3f ", prob[i + j * noPredict]);
+		Rprintf("\n");
 	}
 	destroyOneCoreModel(&modelID);
 
@@ -1247,6 +1307,7 @@ void simRcall() {
 	delete[] interval;
 	delete[] calProb;
 }
+#endif
 
 } //extern "C"
 
