@@ -1,7 +1,7 @@
-#include <stdio.h>    // read and write functions
-#include <string.h>    // dealing with attribute and value names
-#include <stdlib.h>
-#include <float.h>
+#include <cstdio>    // read and write functions
+#include <cstring>    // dealing with attribute and value names
+#include <cstdlib>
+#include <cfloat>
 
 #include "general.h"
 #include "utils.h"
@@ -12,6 +12,8 @@
 #include "mlist.h"
 #include "c45read.h"
 
+using namespace std ;
+
 char nameSeparators[] = "," ;
 char attrSeparators[] = ":" ;
 char datSeparators[] = ",|" ;
