@@ -1,6 +1,5 @@
-#include <stdlib.h>
-#include <stdio.h>
-#include <float.h>
+#include <cstdlib>
+#include <cfloat>
 
 #include "general.h"
 #include "error.h"
@@ -8,6 +7,8 @@
 #include "contain.h"
 #include "utils.h"
 
+using namespace std ;
+
 
 // ***************************************************************************
 //
