@@ -1,5 +1,6 @@
-#include <stdlib.h>
-#include <float.h>
+#include <cstdlib>
+#include <cfloat>
+
 #if defined(_OPENMP)
 #include <omp.h>
 #endif
@@ -12,6 +13,8 @@
 #include "binpart.h"
 #include "options.h"
 
+using namespace std ;
+
 
 // ***************************************************************************
 //
