@@ -5,13 +5,15 @@
 *
 *********************************************************************/
 
-#include <stdlib.h>
+#include <cstdlib>
 
 #include "general.h"
 #include "error.h"
 #include "utils.h"
 #include "regtree.h"
 
+using namespace std ;
+
 //************************************************************
 //
 //                      mdlBottomUpPrune
